#!/usr/bin/python
# Copyright 2007 by Bdale Garbee <bdale@gag.com>.  GPLv2
#
# Program to emit PCB footprint for Samtec BSE connectors

import sys

# dimensions in mm from Bse-d.pdf and BSE.pdf

PinWidth = 0.406
PinHeight = 2.273
PinSpacing = 0.8
RowSpacing = 8.001 - (2 * PinHeight)
HoleDiam = 1.016
HoleOffset= 2.67

# Needs pin count per row on command line, 20/40/60/80/100/120 are valid
positions = int(sys.argv[1])
ordinal = positions / 20.0
if (ordinal < 1) or (ordinal > 6) or (positions%20 != 0):
	sys.stderr.write('Invalid number of positions, must be 20|40|60|80|100|120.\n')
	sys.exit(1)

BodyWidth = (positions * PinSpacing) + 5.27
BodyHeight = 7.24
HoleSpacing = (positions * PinSpacing) + 4.127

# we're going to use the 1/100 of a mil fundamental unit form
def mm2mils100( mm ):
	return int( mm / 25.4 * 1000.0 * 100.0 + 0.5 )

print '# author: Bdale Garbee'
print '# email: bdale@gag.com'
print '# dist-license: GPL 2'
print '# use-license: unlimited'

print 'Element[0x0 "SOIJ8" "" "" 0 0 -10161 -12011 0 100 0x0]'
print "("
for pin in range (0,positions):
    print '   Pad[',\
 	mm2mils100((pin-(positions/2 - 0.5)) * PinSpacing), \
	mm2mils100(-(RowSpacing/2 + PinWidth/2)), \
 	mm2mils100((pin-(positions/2 - 0.5)) * PinSpacing), \
	mm2mils100(-(RowSpacing/2 + PinHeight - PinWidth/2)), \
	mm2mils100(PinWidth), \
	mm2mils100(PinSpacing - PinWidth), \
  	mm2mils100(PinWidth)+600, \
	'"pin%i"' % (2 + pin*2), '"%i"' % (2 + pin*2), '0x0100]'

    print '   Pad[',\
 	mm2mils100((pin-(positions/2 - 0.5)) * PinSpacing), \
	mm2mils100(RowSpacing/2 + PinWidth/2), \
 	mm2mils100((pin-(positions/2 - 0.5)) * PinSpacing), \
	mm2mils100(RowSpacing/2 + PinHeight - PinWidth/2), \
	mm2mils100(PinWidth), \
	mm2mils100(PinSpacing - PinWidth), \
  	mm2mils100(PinWidth)+600, \
	'"pin%i"' % (1 + pin*2), '"%i"' % (1 + pin*2), '0x0100]'

print '   Pin[', \
    mm2mils100(HoleSpacing/2), \
    mm2mils100(-HoleOffset), \
    mm2mils100(HoleDiam), \
    0, \
    mm2mils100(HoleDiam), \
    mm2mils100(HoleDiam), \
    '"mnt" "0"', '0x0008', ']'

print '   Pin[', \
    mm2mils100(-HoleSpacing/2), \
    mm2mils100(-HoleOffset), \
    mm2mils100(HoleDiam), \
    0, \
    mm2mils100(HoleDiam), \
    mm2mils100(HoleDiam), \
    '"mnt" "0"', '0x0008', ']'

print '   ElementLine[',\
 	mm2mils100(-BodyWidth/2), \
	mm2mils100(-BodyHeight/2), \
	mm2mils100(-BodyWidth/2), \
	mm2mils100( BodyHeight/2), \
	'1000 ]'

print '   ElementLine[',\
 	mm2mils100(-BodyWidth/2), \
	mm2mils100( BodyHeight/2), \
	mm2mils100( BodyWidth/2), \
	mm2mils100( BodyHeight/2), \
	'1000 ]'

print '   ElementLine[',\
 	mm2mils100( BodyWidth/2), \
	mm2mils100( BodyHeight/2), \
	mm2mils100( BodyWidth/2), \
	mm2mils100(-BodyHeight/2), \
	'1000 ]'

print '   ElementLine[',\
 	mm2mils100( BodyWidth/2), \
	mm2mils100(-BodyHeight/2), \
	mm2mils100(-BodyWidth/2), \
	mm2mils100(-BodyHeight/2), \
	'1000 ]'

print '   ElementArc[',\
 	mm2mils100(-(positions/2 + 0.5) * PinSpacing), \
	mm2mils100(RowSpacing/2+PinHeight*5/4), \
	'500 500 0 360 1000 ]'

print ")"
