#! perl -w
#
#####################################################
#
#  This is a quickie Perl prog which takes the model files
#  distributed with Linear Tech's SwitcherCADIII, blows them apart,
#  and creates a set of individual model files compatible with 
#  the gEDA spice-SDB netlister.  
#
#  The output files created are named after the name of the
#  model itself; the suffix .mod is appended to the model
#  name to create the model name.
#
#  I wrote this quickie prog in order to populate my models/spice
#  directory with spice models quickly.
#
#  Usage:  perl MakeLTCModels.pl < standard.foo
#  where foo = 
#              bjt
#              cap
#              dio
#              etc. etc. etc.
#
#  3.15.2003 -- SDB
#
######################################################
# This prog is a simple state machine -- it's activity depends
# upon it's current state.
# States are:
# 0:  Searching for ".model".  Write out first line when found.
# 1:  Searching for "+".  Write out line when "+" is found;
#     abort and return to state 0 if a non-continued line is found.

$StateCounter = 0;


while (1) {
#------------------------  State 0 -------------------------
    if ($StateCounter == 0) {   # We are looking for .model
        do {
            if (eof(STDIN)) {
                die "EOF found in state 0.  All done. . . . \n";
	    }
	    $Line = <STDIN>;
            
        } until ( ($Line =~ /^.MODEL /) || ($Line =~ /^.model /) );
	print "Found another .model . . .  \n";
        @List = split(/\s+/, $Line);             
        $Model = $List[1];         # Extract model name from line
	$OutputFilename = $Model.".mod";

	open(OUTPUTFILE, ">$OutputFilename");
	print ("$Line");
	print OUTPUTFILE $Line;
	
	$StateCounter = 1;
    }

#------------------------  State 1 -------------------------
    elsif ($StateCounter == 1) { # we are looking for "+" at beginning of line.
	$Line = <STDIN>;
	if ($Line =~ /^\+ /) {
	    print ("$Line");
	    print OUTPUTFILE $Line;
	    $StateCounter = 1;
	}
	else {
	    print "\n";
	    $StateCounter = 0;
	    close(OUTPUTFILE);
	}
    }
}
